@@ -1,8 +1,8 @@
-from conductor.client.configuration.settings.authentication_settings import AuthenticationSettings
-from six.moves import http_client as httplib
 import logging
-import multiprocessing
 import os
+import time
+
+from conductor.client.configuration.settings.authentication_settings import AuthenticationSettings
 
 
 class Configuration:
@@ -10,14 +10,36 @@ class Configuration:
 
     def __init__(
             self,
-            base_url: str = "http://localhost:8080",
+            base_url: str = None,
             debug: bool = False,
-            authentication_settings: AuthenticationSettings = None
+            authentication_settings: AuthenticationSettings = None,
+            server_api_url: str = None,
+            auth_token_ttl_min: int = 45
     ):
-        self.host = base_url
-        self.temp_folder_path = None
+        if server_api_url is not None:
+            self.host = server_api_url
+        elif base_url is not None:
+            self.host = base_url + '/api'
+        else:
+            self.host = os.getenv('CONDUCTOR_SERVER_URL')
 
-        self.authentication_settings = authentication_settings
+        if self.host is None:
+            self.host = 'http://localhost:8080/api'
+
+        self.temp_folder_path = None
+        self.__ui_host = os.getenv('CONDUCTOR_UI_SERVER_URL')
+        if self.__ui_host is None:
+            self.__ui_host = self.host
+
+        if authentication_settings is not None:
+            self.authentication_settings = authentication_settings
+        else:
+            key = os.getenv('CONDUCTOR_AUTH_KEY')
+            secret = os.getenv('CONDUCTOR_AUTH_SECRET')
+            if key is not None and secret is not None:
+                self.authentication_settings = AuthenticationSettings(key_id=key, key_secret=secret)
+            else:
+                self.authentication_settings = None
 
         # Debug switch
         self.debug = debug
@@ -37,18 +59,18 @@ class Configuration:
         # Set this to True/False to enable/disable SSL hostname verification.
         self.assert_hostname = None
 
-        # urllib3 connection pool's maximum number of connections saved
-        # per pool. urllib3 uses 1 connection as default value, but this is
-        # not the best value when you are making a lot of possibly parallel
-        # requests to the same host, which is often the case here.
-        # cpu_count * 5 is used as default value to increase performance.
-        self.connection_pool_maxsize = multiprocessing.cpu_count() * 5
-
         # Proxy URL
         self.proxy = None
         # Safe chars for path_param
         self.safe_chars_for_path_param = ''
 
+        # Provide an alterative to requests.Session() for HTTP connection.
+        self.http_connection = None
+
+        # not updated yet
+        self.token_update_time = 0
+        self.auth_token_ttl_msec = auth_token_ttl_min * 60 * 1000
+
     @property
     def debug(self):
         """Debug status
@@ -67,12 +89,8 @@ class Configuration:
         """
         self.__debug = value
         if self.__debug:
-            # turn on httplib debug
-            httplib.HTTPConnection.debuglevel = 1
             self.__log_level = logging.DEBUG
         else:
-            # turn off httplib debug
-            httplib.HTTPConnection.debuglevel = 0
             self.__log_level = logging.INFO
 
     @property
@@ -97,12 +115,37 @@ class Configuration:
         """
         self.__logger_format = value
 
-    def apply_logging_config(self):
+    @property
+    def log_level(self):
+        """The log level.
+
+        The log_level will be updated when sets logger_format.
+
+        :param value: The format string.
+        :type: str
+        """
+        return self.__log_level
+
+    @property
+    def ui_host(self):
+        """
+
+        The log_level will be updated when sets logger_format.
+
+        :param value: The format string.
+        :type: str
+        """
+        return self.__ui_host
+
+    def apply_logging_config(self, log_format : str = None, level = None):
+        if log_format is None:
+            log_format = self.logger_format
+        if level is None:
+            level = self.__log_level
         logging.basicConfig(
-            format=self.logger_format,
-            level=self.__log_level
+            format=log_format,
+            level=level
         )
-        logging.getLogger('urllib3').setLevel(logging.WARNING)
 
     @staticmethod
     def get_logging_formatted_name(name):
@@ -110,3 +153,4 @@ class Configuration:
 
     def update_token(self, token: str) -> None:
         self.AUTH_TOKEN = token
+        self.token_update_time = round(time.time() * 1000)
